==> restful-1.49.6-sources.jar: com/aote/module/ModuleMapper.java <==
package com.aote.module;

import com.aote.exception.FileNotFoundException;
import com.aote.logic.LogicMapper;
import com.aote.util.ResourceHelper;
import org.apache.log4j.Logger;
import org.dom4j.Document;
import org.dom4j.Element;
import org.dom4j.io.SAXReader;
import org.json.JSONArray;
import org.json.JSONObject;

import java.io.IOException;
import java.io.InputStream;
import java.util.HashMap;
import java.util.Iterator;
import java.util.LinkedHashMap;
import java.util.Map;

public class ModuleMapper {

	static Logger log = Logger.getLogger(LogicMapper.class);

	private static Map<String, Map<String, String>> map;
	private static Map<String, Map<String, String>> subclassmap;

	static {
		//初始化即加载
		loadMap();
		loadSubClassMap();
	}

	public static String getAttr(String module, String attr) {
		if(map.containsKey(module)) {
            return map.get(module).get(attr);
        } else {
            return null;
        }
	}
	/**
	 * 获取继承关系模块配置文件
	 * @return
	 */
	public static Map<String, Map<String, String>> getSubClassMap() {
		return subclassmap;
	}

	/**
	 * 获取所有模块映射文件
	 * @return
	 */
	public static Map<String, Map<String, String>> getMap() {
		return map;
	}

	private static void loadSubClassMap() {
		subclassmap = new LinkedHashMap<>();

        if (ResourceHelper.class.getResourceAsStream("/"+ "subclass.json") == null) {
            log.debug("无subclass.json文件，继承关系模块化无");
            return;
        }
        String strConfig;
		try {
			strConfig = ResourceHelper.getString("subclass.json");
		} catch (FileNotFoundException e) {
			throw new RuntimeException("subclass.json文件无配置");
		} catch (IOException io) {
			throw new RuntimeException(io);
		}

        JSONArray json = new JSONArray(strConfig);
        for (Object obj : json) {
		  JSONObject jo = (JSONObject)obj;
		  String name = jo.getString("module");
		  Map<String, String> module = new HashMap<>();
		  module.put("name", name);
		  subclassmap.put(name, module);
		}
	}


	@SuppressWarnings("rawtypes")
	private static void loadMap() {
		map = new LinkedHashMap<>();

		InputStream module = LogicMapper.class.getClassLoader()
				.getResourceAsStream("module.xml");
		try {
			if (module == null) {
				throw new RuntimeException("模块定义文件module.xml未找到");
			}
			parseModule(module);
		} catch (Exception ex) {
			ex.printStackTrace();
		}

	}

	private static void parseModule(InputStream input) throws Exception {
		SAXReader reader = new SAXReader();
		Document document = reader.read(input);
		Element root = document.getRootElement();
		String mode = root.attributeValue("mode");
		if((mode == null || mode.equals("debug"))){
			log.warn("检测到已在module.xml中开启调试模式(mode='debug')，业务资源懒加载优化已关闭");
			log.warn("生产环境下建议关闭该模式，以避免每次访问业务资源所带来的不必要的IO消耗");
			ResourceHelper.mode = ResourceHelper.CACHE_MODE.DEBUG;
		} else {
			log.info("业务资源懒加载优化已开启，Logic/SQL缓存成功，可以通过rs/logic/clear强制清理缓存");
		}
		for (Iterator<Element> it = root.elementIterator("module"); it.hasNext();) {
			Element elm = it.next();
			String name = elm.attribute("name").getValue();
			String upload = elm.attributeValue("upload");
			String path = elm.attributeValue("path");
			// 设置module属性
			Map<String, String> module = new HashMap<>();
			module.put("name", name);
			module.put("upload", upload);
			module.put("path", path);
			map.put(name, module);
		}
	}
}

==> restful-1.50.5-sources.jar: com/aote/module/ModuleMapper.java <==
package com.aote.module;

import com.aote.config.SystemConfig;
import com.aote.exception.FileNotFoundException;
import com.aote.logic.LogicMapper;
import com.aote.util.ResourceHelper;
import org.apache.log4j.Logger;
import org.dom4j.Document;
import org.dom4j.Element;
import org.dom4j.io.SAXReader;
import org.json.JSONArray;
import org.json.JSONObject;

import java.io.IOException;
import java.io.InputStream;
import java.util.HashMap;
import java.util.Iterator;
import java.util.LinkedHashMap;
import java.util.Map;

public class ModuleMapper {

	static Logger log = Logger.getLogger(LogicMapper.class);

	private static Map<String, Map<String, String>> map;
	private static Map<String, Map<String, String>> subclassmap;

	static {
		//初始化即加载
		loadMap();
		loadSubClassMap();
	}

	public static String getAttr(String module, String attr) {
		if(map.containsKey(module)) {
            return map.get(module).get(attr);
        } else {
            return null;
        }
	}
	/**
	 * 获取继承关系模块配置文件
	 * @return
	 */
	public static Map<String, Map<String, String>> getSubClassMap() {
		return subclassmap;
	}

	/**
	 * 获取所有模块映射文件
	 * @return
	 */
	public static Map<String, Map<String, String>> getMap() {
		return map;
	}

	private static void loadSubClassMap() {
		subclassmap = new LinkedHashMap<>();

        JSONArray json = SystemConfig.SubClass.getSubClassArray();
		if (json != null) {
			for (Object obj : json) {
				String name = String.valueOf(obj);
				Map<String, String> module = new HashMap<>(json.length());
				module.put("name", name);
				subclassmap.put(name, module);
			}
		}
	}


	@SuppressWarnings("rawtypes")
	private static void loadMap() {
		map = new LinkedHashMap<>();

		InputStream module = LogicMapper.class.getClassLoader()
				.getResourceAsStream("module.xml");
		try {
			if (module == null) {
				throw new RuntimeException("模块定义文件module.xml未找到");
			}
			parseModule(module);
		} catch (Exception ex) {
			ex.printStackTrace();
		}

	}

	private static void parseModule(InputStream input) throws Exception {
		SAXReader reader = new SAXReader();
		Document document = reader.read(input);
		Element root = document.getRootElement();
		String mode = root.attributeValue("mode");
		if((mode == null || mode.equals("debug"))){
			log.warn("检测到已在module.xml中开启调试模式(mode='debug')，业务资源懒加载优化已关闭");
			log.warn("生产环境下建议关闭该模式，以避免每次访问业务资源所带来的不必要的IO消耗");
			ResourceHelper.mode = ResourceHelper.CACHE_MODE.DEBUG;
		} else {
			log.info("业务资源懒加载优化已开启，Logic/SQL缓存成功，可以通过rs/logic/clear强制清理缓存");
		}
		for (Iterator<Element> it = root.elementIterator("module"); it.hasNext();) {
			Element elm = it.next();
			String name = elm.attribute("name").getValue();
			String upload = elm.attributeValue("upload");
			String path = elm.attributeValue("path");
			// 设置module属性
			Map<String, String> module = new HashMap<>();
			module.put("name", name);
			module.put("upload", upload);
			module.put("path", path);
			map.put(name, module);
		}
	}
}
